Coverage for /media/ldata/code/tendril/tendril/frontend/blueprints/testing/views.py: 0%

# Coverage for /media/ldata/code/tendril/tendril/frontend/blueprints/testing/views.py : 0%

## 22 statements 0 run 22 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 | #!/usr/bin/env python # encoding: utf-8 # Copyright (C) 2015 Chintalagiri Shashank # # This file is part of tendril. # # This program is free software: you can redistribute it and/or modify # it under the terms of the GNU Affero General Public License as published by # the Free Software Foundation, either version 3 of the License, or # (at your option) any later version. # # This program is distributed in the hope that it will be useful, # but WITHOUT ANY WARRANTY; without even the implied warranty of # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the # GNU Affero General Public License for more details. # # You should have received a copy of the GNU Affero General Public License # along with this program. If not, see <http://www.gnu.org/licenses/>. """ Docstring for views """ from flask import render_template from flask_user import login_required from . import testing as blueprint from tendril.dox import testing as dxtesting from tendril.utils.fsutils import Crumb @blueprint.route('/result/<device_sno>') @blueprint.route('/result/') @login_required def results(device_sno=None): # Presently only supports getting the latest result. A way to allow # any result to be retrieved would be nice. if device_sno is None: docs = dxtesting.get_all_test_reports() stage = {'docs': docs, 'crumbroot': '/testing', 'breadcrumbs': [Crumb(name="Testing", path="/"), Crumb(name="Results", path="result/")], } return render_template('test_results.html', stage=stage, pagetitle="All Test Results") else: docs = dxtesting.get_latest_test_report(device_sno) stage = {'docs': docs, 'crumbroot': '/testing', 'breadcrumbs': [Crumb(name="Testing", path="/"), Crumb(name="Reports", path="result/"), Crumb(name=device_sno, path="result/" + device_sno)], # noqa } return render_template('test_result_detail.html', stage=stage, pagetitle=device_sno + " Test Result") @blueprint.route('/') @login_required def main(): latest = dxtesting.get_all_test_reports(limit=5) stage = {'latest': latest, 'crumbroot': '/testing', 'breadcrumbs': [Crumb(name="Testing", path="/")], } return render_template('testing_main.html', stage=stage, pagetitle='Testing')